@@ -181,11 +181,12 @@ glade_placeholder_realize (GtkWidget *widget)
 	attributes.wclass = GDK_INPUT_OUTPUT;
 	attributes.visual = gtk_widget_get_visual (widget);
 	attributes.colormap = gtk_widget_get_colormap (widget);
-	attributes.event_mask = gtk_widget_get_events (widget) |
-				GDK_EXPOSURE_MASK              |
-				GDK_BUTTON_PRESS_MASK          |
-		                GDK_BUTTON_RELEASE_MASK        |
-		                GDK_POINTER_MOTION_MASK;
+	attributes.event_mask = 
+		gtk_widget_get_events (widget) |
+		GDK_EXPOSURE_MASK              |
+		GDK_BUTTON_PRESS_MASK          |
+		GDK_BUTTON_RELEASE_MASK        |
+		GDK_POINTER_MOTION_MASK;
 
 	attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
 
