@@ -14,6 +14,7 @@
 #include <glib.h>
 #include <errno.h>
 
+#include "glade.h"
 #include "glade-xml-utils.h"
 
 #include <libxml/tree.h>
@@ -21,6 +22,8 @@
 #include <libxml/parserInternals.h>
 #include <libxml/xmlmemory.h>
 
+#include "glade-utils.h"
+
 struct _GladeXmlNode
 {
 	xmlNodePtr node;
@@ -193,23 +196,24 @@ glade_xml_node_verify (GladeXmlNode *node_in, const gchar *name)
 gboolean
 glade_xml_get_value_int (GladeXmlNode *node_in, const gchar *name, gint *val)
 {
-	xmlNodePtr node = (xmlNodePtr) node_in;
-	gchar *ret;
-	gint i;
-	gint res;
+        xmlNodePtr node = (xmlNodePtr) node_in;
+        gchar *value, *endptr = NULL;
+        gint64 i;
 
-	ret = glade_xml_get_value (node, name);
-	if (ret == NULL) return 0;
-	res = sscanf (ret, "%d", &i);
-	g_free (ret);
+        value = glade_xml_get_value (node, name);
+        if (value == NULL)
+                return FALSE;
 
-	if (res == 1)
-	{
-	        *val = i;
-		return TRUE;
-	}
+        errno = 0;
+        i = glade_util_ascii_strtoll (value, &endptr, 10);
+        if (errno != 0 || (i == 0 && endptr == value)) {
+                g_free (value);
+                return FALSE;
+        }
 
-	return FALSE;
+        g_free (value);
+        *val = (gint) i;
+        return TRUE;
 }
 
 /**
